@@ -25,14 +25,15 @@ class EtsyAuth:
     __base_endpoint:str = "https://openapi.etsy.com/v3/application/"
     
     
-    @property
-    def get_user_info(self):
+    
+    def __post_init__(self):
         user_info_endpoint = "oauth/userinfo"
-        
-        response = self.request(user_info_endpoint)
-        
-        return OtherUser(**response)
-        
+        response = self.request(user_info_endpoint, params={"client_id":self.session.client_id})
+        setattr(self, "user_info", OtherUser(**response))
+    
+    @property
+    def get_shop_id_self_user(self):
+        pass
         
     def request(self, endpoint: str, method="GET", *args, **kwargs) -> dict:
         """ 
